#!/usr/bin/env python

'''metameta - metatranscriptome to metagenome mapping analysis toolset

Usage:

    metameta <tool> [arguments for tool]

    metameta with no <tool> or arguments will give help on the package
    <tool> without any arguments will give the help for that tool

Tools:
'''

import sys
import subprocess
import argparse

def tool_check(desired_tool):
    tools = ['test']
    for tool in tools:
        if desired_tool == tool:
            return desired_tool
    print('No such tool: ' + desired_tool)
    print('Available tools:')
    for tool in tools:
        print(tool)
    sys.exit(1)

if __name__ == '__main__':
    parser = argparse.ArgumentParser(description = __doc__,
                                     formatter_class=argparse.\
                                     RawDescriptionHelpFormatter)
    parser.add_argument('tool',
                        type = tool_check,
                        default = None,
                        nargs = '?',
                        help = 'tool to run')
    parser.add_argument('arguments',
                        nargs = argparse.REMAINDER,
                        help = 'arguments to pass to tool')
    args = parser.parse_args()
    
    if args.tool == None:
        print(__doc__)
    elif args.arguments == [] and args.tool != None:
        script = 'metameta/' + args.tool + '.py'
        subprocess.call(['python', script])
    else:
        pass
        #TODO: call other program with subprocess



#!/usr/bin/env python

from setuptools import setup

setup(name = 'metameta',
      version = '0.0.0.2',
      description = 'Toolset for analyzing'\
          + 'metatranscriptome data mapped onto metagenomic data',
      classifiers = [
            'Development Status :: 1 - Planning',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
            'Natural Language :: English',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 3.4',
            'Topic :: Scientific/Engineering :: Bio-Informatics'
          ],
      keywords = 'bioinformatics metadata metagenome metatranscriptome'\
          + 'short reads mapping alignment',
      url = 'https://github.com/Brazelton-Lab/metameta',
      download_url = 'https://github.com/Brazelton-Lab/metameta/tarball/'\
          + '0.0.0.2',
      author = 'Alex Hyer',
      author_email = 'theonehyer@gmail.com',
      license = 'GPL',
      packages = ['metameta'],
      include_package_data = True,
      zip_safe = False,
      test_suite = 'nose.collector',
      tests_require = ['nose'],
      entry_points = {
          'console_scripts':['metameta=metameta.__main__:main']
          }
      )
